@@ -5,7 +5,7 @@ from rigour.names import remove_obj_prefixes
 from followthemoney.proxy import E, EntityProxy
 from followthemoney import model
 from followthemoney.types import registry
-from rigour.names import schema_type_tag
+from followthemoney.names import schema_type_tag
 
 from nomenklatura.matching.logic_v2.names.analysis import entity_names
 from nomenklatura.matching.logic_v2.names.magic import weight_extra_match
